@@ -10,7 +10,7 @@
 
 // :cppFile:{FCT_buyseTest.cpp}:end:
 
-arma::mat calcAllPairs(arma::colvec endpointC, arma::colvec endpointT, double threshold, double restriction,
+arma::mat calcAllPairs(arma::colvec endpointC, arma::colvec endpointT, double threshold, bool threshold0, double restriction,
 					   arma::colvec statusC, arma::colvec statusT,					   
 					   arma::mat survTimeC, arma::mat survTimeT, arma::mat survJumpC, arma::mat survJumpT,
 					   arma::rowvec lastSurv, 					   
@@ -64,7 +64,7 @@ void add4vec(std::vector<int>& Vrow,
 //         RP_Dscore_Dnuisance_C, RP_Dscore_Dnuisance_T
 //         matPairScore
 // author Brice Ozenne
-arma::mat calcAllPairs(arma::colvec endpointC, arma::colvec endpointT, double threshold, double restriction,
+arma::mat calcAllPairs(arma::colvec endpointC, arma::colvec endpointT, double threshold, bool threshold0, double restriction,
 					   arma::colvec statusC, arma::colvec statusT,					   
 					   arma::mat survTimeC, arma::mat survTimeT, arma::mat survJumpC, arma::mat survJumpT,
 					   arma::rowvec lastSurv,
@@ -206,9 +206,9 @@ arma::mat calcAllPairs(arma::colvec endpointC, arma::colvec endpointT, double th
       }
       iPairScore = calcOnePair_Gaussian(endpointT[iter_C], endpointC[iter_T], statusC[iter_C], statusT[iter_T], iRho, threshold);
     }else if(method == 3){ // time to event endpoint with Gehan's scoring rule (right-censored, survival or competing risks)
-      iPairScore = calcOnePair_TTEgehan(endpointT[iter_T] - endpointC[iter_C], statusC[iter_C], statusT[iter_T], threshold);
+      iPairScore = calcOnePair_TTEgehan(endpointT[iter_T] - endpointC[iter_C], statusC[iter_C], statusT[iter_T], threshold, threshold0);
     }else if(method == 4){ // time to event endpoint with Gehan's scoring rule (left-censored, survival or competing risks)
-      iPairScore = calcOnePair_TTEgehan2(endpointT[iter_T] - endpointC[iter_C], statusC[iter_C], statusT[iter_T], threshold);
+      iPairScore = calcOnePair_TTEgehan2(endpointT[iter_T] - endpointC[iter_C], statusC[iter_C], statusT[iter_T], threshold, threshold0);
     }else if(method == 5){  // time to event endpoint with Peron's scoring rule (right-censored, survival)
       iPairScore = calcOnePair_SurvPeron(endpointC[iter_C], endpointT[iter_T], statusC[iter_C], statusT[iter_T], threshold, restriction,
 					 survTimeC.row(iter_C), survTimeT.row(iter_T),
